import { ValidationError } from 'class-validator';
import { AllowPrimitives } from '../../../../types';
/**
* Short version of graphic field representation
*/
export interface iRGraphicField {
    /**
    * Image file in base64 url representation
    * @type {string}
    */
    src: string;
    /**
    * Image width
    * @type {number}
    */
    width: number;
    /**
    * Image height
    * @type {number}
    */
    height: number;
}
/**
* Short version of graphic field representation
*/
export declare class RGraphicField implements iRGraphicField {
    /**
    * Image file in base64 url representation
    * @type {string}
    */
    src: string;
    /**
    * Image width
    * @type {number}
    */
    width: number;
    /**
    * Image height
    * @type {number}
    */
    height: number;
    /**
    * Create instance of RGraphicField from plain object
    * @param {AllowPrimitives<iRGraphicField>} input - plain object
    * @returns {RGraphicField}
    */
    static fromPlain: (input: AllowPrimitives<iRGraphicField>) => RGraphicField;
    /**
    * Get validation errors of RGraphicField
    * @param {RGraphicField} input - RGraphicField object
    * @returns {ValidationError[]}
    */
    static getValidationErrors: (input: RGraphicField) => ValidationError[];
    /**
    * Check if RGraphicField is valid
    * @param {RGraphicField | RGraphicField[]} input - RGraphicField object or array of RGraphicField objects
    * @returns {boolean}
    */
    static isValid: (input: RGraphicField | RGraphicField[]) => boolean;
}
